#!/usr/bin/env python3.6

'''
This script generates the fully annotated CoNLL2009 data with the SRL annotation conducted in the CLARIN-D curation project 'Semantic Annotation for Digital Humanitites' with VerbNet-like semantic roles.
See more on http://www.cl.uni-heidelberg.de/projects/GNVN_semanno/.

This work is licensed under the Creative Commons Attribution-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/4.0/.

Website: http://www.cl.uni-heidelberg.de/projects/GNVN_semanno/
Contact: Eva Mujdricza-Maydt, mujdricza@cl.uni-heidelberg.de
'''

__author__ = "mujdricza-maydt"
__contact__ = "mujdricza@cl.uni-heidelberg.de"
__version__ = "20170810"


# imports of python3 and external modules/packages
import argparse
import sys

# local imports 
import utils_io as utilsio

def load_argument_parser(print_help=False):
    parser = argparse.ArgumentParser(
        description='creates the GNVN CoNLL2009 data annotated with VerbNet-like semantic roles')
    parser.add_argument(
        '-c', dest="path_to_original_conll2009_germandata", type=str, required=True,
        help='path to CoNLL2009 German annotation data in conll format (licence available by https://catalog.ldc.upenn.edu/LDC2012T03)')
    parser.add_argument(
        '-i', dest="path_to_gnvn_conll2009srlonly_data", type=str, default="../data/GNVN_conll2009-onlySRL/",
        help='path to the GNVN data including only SRL annotation (optional -- if not given, included data in the "data" folder will be used)')
    parser.add_argument(
        '-o', dest="output_path_gnvn_conll2009full", type=str, default="../data/GNVN_conll2009/", 
        help='output path for the GNVN full annotation data (optional -- if not given, the included "data" folder is the destination)')
    
    if print_help:
        parser.print_help()
    
    return parser

    
def generate_dataset(input_file_name_gnvn_onlySRL, input_file_name_conll2009, output_file_name_gnvn):
    '''
    Writes the fully annotated CoNLL2009 data for the given dataset (train, dev, test) with the SRL annotation conducted in the CLARIN-D curation project 'Semantic Annotation for Digital Humanitites' with VerbNet-like semantic roles.     
     
    :param input_file_name_gnvn_onlySRL: dataset file with the GNVN SRL annotations only
    :param input_file_name_conll2009: original CoNLL2009 file for the given dataset (with PropBank SRL annotation)
    :param output_file_name_gnvn: output file name for the compiled CoNLL2009 data with the GNVN SRL annotation 
    :return: None
    '''
    
    #read
    gnvn_onlySRL_sentence_list = utilsio.read_tabulated(input_file_name_gnvn_onlySRL)
    conll2009_sentence_list = utilsio.read_tabulated(input_file_name_conll2009)
    
    #compile
    fully_annotated_sentence_list = utilsio.get_fully_annotated_sentence_list(gnvn_onlySRL_sentence_list, conll2009_sentence_list)
    
    #write
    utilsio.write_tabulated(output_file_name_gnvn, fully_annotated_sentence_list)
    

def main_create_GNVN_CoNLL2009_data():
    '''
    Writes the fully annotated CoNLL2009 data with the SRL annotation conducted in the CLARIN-D curation project 'Semantic Annotation for Digital Humanitites' with VerbNet-like semantic roles. 
    '''
    
    args = sys.argv
    
    input_path_conll2009 = None
    input_path_gnvn_onlySRL = None
    output_path = None
    
    if len(args) < 2:
        load_argument_parser(True)
        sys.exit(1)
    elif len(args) == 2 and args[1] == "hard":
        input_path_gnvn_onlySRL = "../data/GNVN_conll2009-onlySRL/"
        input_path_conll2009 =  "/Users/eva/my/uni/CLARIN-D/KP3/KP3B/Data/rawData/CoNLL2009-ST/"
        output_path = "../data/GNVN_conll2009/"
    
    else:
        argparser = load_argument_parser()
        args = argparser.parse_args()
    
        input_path_conll2009 = utilsio.normalize_path(args.path_to_original_conll2009_germandata)
        input_path_gnvn_onlySRL = utilsio.normalize_path(args.path_to_gnvn_conll2009srlonly_data)
        output_path = utilsio.normalize_path(args.output_path_gnvn_conll2009full)
        
    
    utilsio.create_path_if_needed(output_path)
    subfolders = list(utilsio.DATASET._value2member_map_.keys())
    utilsio.create_path_structure(output_path, subfolders)
    print("OUTPUT PATH for the GNVN corpus: '{}' with {} subfolders {}".format(output_path, len(subfolders), subfolders))
    
    for dataset in subfolders:
        input_file_name_conll2009 = input_path_conll2009 + utilsio.CoNLL2009_FILES.__members__[dataset].value
        input_file_name_gnvn_onlySRL = input_path_gnvn_onlySRL + dataset + "/" + utilsio.GNVN_CoNLL2009onlySRL_FILES.__members__[dataset].value
        output_file_name_gnvn = output_path + dataset + "/" + utilsio.GNVN_CoNLL2009_FILES.__members__[dataset].value
        
        print("Compiling '{}' from '{}' + '{}'".format(output_file_name_gnvn, input_file_name_conll2009, input_file_name_gnvn_onlySRL))
        generate_dataset(input_file_name_gnvn_onlySRL, input_file_name_conll2009, output_file_name_gnvn)
        
    
    print("(DONE)")
        
    
if __name__ == "__main__":
    main_create_GNVN_CoNLL2009_data()